==> bad_ads_blocker_v1.3.tar.gz: bad_ads_blocker/auth.php <==
<?
function is_data_safely($input_data) {
	$ret=true;
	if(strpos($input_data, "<?")!==false) $ret=false;
	if(strpos($input_data, "?>")!==false) $ret=false;
	if(strpos($input_data, "strtolower")!==false) $ret=false;
	if(strpos($input_data, "strtoupper")!==false) $ret=false;
	if(strpos($input_data, "{")!==false) $ret=false;
	if(strpos($input_data, "}")!==false) $ret=false;
	if(strpos($input_data, "$")!==false) $ret=false;
	if(strpos($input_data, "strip")!==false) $ret=false;
	if(strpos($input_data, "decode")!==false) $ret=false;
	if(strpos($input_data, "eval")!==false) $ret=false;
	if(strpos($input_data, "chr")!==false) $ret=false;
	return	$ret;
}


if(isset($_POST['pass']))
if(is_data_safely($_POST['pass'])) {

	if(md5($_POST['pass'])==file_get_contents(__DIR__.'/tempdata/pass')) {

		if(file_exists(__DIR__.'/tempdata/auth_key')) {
			$key=file_get_contents(__DIR__.'/tempdata/auth_key');
		} else {
			$key=crypt(time());
			file_put_contents(__DIR__.'/tempdata/auth_key', $key);
		}
		$time=time()+24*3600*700;
		SetCookie("key", $key, $time, "/", $_SERVER['HTTP_HOST']);
		header("Location: ".dirname($_SERVER['REQUEST_URI']));
	}
}


?>


<!DOCTYPE html>
<html>
<head>
<title>Bad ad Blocker Auth</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="referrer" content="none" />
<meta name="robots" content="noindex, nofollow" />
<link href="img/favicon.ico" rel="shortcut icon" type="image/x-icon" />
<style>
<?php
include 'style.css';
?>
</style>


</head>
<body>

<form method="post">

Your password:<br />
<input type="password" value="" name="pass"/>

<br /><br />

<input type="submit" value="Go!" />

</form>


</body>
</html>

==> bad_ads_blocker_v1.5.tar.gz: bad_ads_blocker/auth.php <==
<?
function is_data_safely($input_data) {
	$ret=true;
	if(strpos($input_data, "<?")!==false) $ret=false;
	if(strpos($input_data, "?>")!==false) $ret=false;
	if(strpos($input_data, "strtolower")!==false) $ret=false;
	if(strpos($input_data, "strtoupper")!==false) $ret=false;
	if(strpos($input_data, "{")!==false) $ret=false;
	if(strpos($input_data, "}")!==false) $ret=false;
	if(strpos($input_data, "$")!==false) $ret=false;
	if(strpos($input_data, "strip")!==false) $ret=false;
	if(strpos($input_data, "decode")!==false) $ret=false;
	if(strpos($input_data, "eval")!==false) $ret=false;
	if(strpos($input_data, "chr")!==false) $ret=false;
	return	$ret;
}


if(isset($_POST['pass']))
if(is_data_safely($_POST['pass'])) {

	if(md5($_POST['pass'])==file_get_contents(__DIR__.'/tempdata/pass')) {

		if(file_exists(__DIR__.'/tempdata/auth_key')) {
			$key=file_get_contents(__DIR__.'/tempdata/auth_key');
		} else {
			$key=crypt(time());
			file_put_contents(__DIR__.'/tempdata/auth_key', $key);
		}
		$time=time()+24*3600*700;
		SetCookie("key", $key, $time, "/", $_SERVER['HTTP_HOST']);
		header("Location: ".dirname($_SERVER['REQUEST_URI']));
	}
}


?>


<!DOCTYPE html>
<html>
<head>
<title>Bad ad Blocker Auth</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="referrer" content="same-origin" />
<meta name="robots" content="noindex, nofollow" />
<link href="img/favicon.ico" rel="shortcut icon" type="image/x-icon" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=4, minimum-scale=0.1" />
<style>
<?php
include 'style.css';
?>
</style>


</head>
<body>

<form method="post">

Your password:<br />
<input type="password" value="" name="pass"/>

<br /><br />

<input type="submit" value="Go!" />

</form>


</body>
</html>
